#include "ti86asm.inc"

.org _asm_exec_ram

	nop
	jp ProgStart
	.dw 0
	.dw ShellTitle

ShellTitle:
	.db "Oxidation States v1.0",0

ProgStart:
	ld a,1					;initialize the anion and cation
	ld (Name),a				;number @ 0
	call _clrScrn
	call _runindicoff		;turn the run indicator off

MainLoop:
	call DrawScreen			;call routine to draw everything to the screen
NoRedraw:
	call _GET_KEY			;call routine to get key presses
	cp K_UP					;subtract a-k7
	jp z,Mup				;is zero flag set(a=k7)? if so scroll Cations up
	cp K_DOWN				;if 4 is pressed scroll cations down
	jp z,Mdown
	cp K_EXIT				;if exit is pressed then exit the program
	jp z,end
	cp 0
	jr z,NoRedraw
	call Search
	jr MainLoop


end:
	call _clrLCD
	ret						; end program

Mup:
	ld a,(Name)			;load Cation # into register a
	cp 1					;if it's 0 then don't scroll up anymore
	jp z,NoRedraw
	dec a					;if not then scroll up
	ld (Name),a
	jp MainLoop				;go back to main loop

Mdown:
	ld a,(Name)			;same as above, but down
	cp 99
	jp z,NoRedraw
	inc a
	ld (Name),a
	jp MainLoop


DrawScreen:					;routine that calls the other routines that
	call DrawBack			;draw everything to the LCD
	call PutNames
	call PutFormulas
	ret

DrawBack:					;draws the background
	ld de,$fc10				;loads address for LCD into de
	ld hl,BackGround		;background points to hl
	ld bc,$3F0				;how many times to loop
	ldir 					;loop until bc = 0 while loading hl into de
	ret

PutNames:	
	ld a,(Name)			;load anion number into register a
	ld h,a					;these next few commands multiply anion by 11
	ld l,22
	call _HtimesL
	ld e,l
	ld d,h
	ld hl,Names			;hl points to anion list
	add hl,de				;add offset to list
	ld b,7					;initialize loop counter
	ld e,0					;number for _penCol
PutNLoop:
	ld a,7					;these command subtract b from 7 and multiply it by 8
	sub b					;7 - b = a
	add a,a					;a*2
	add a,a					;a*4
	add a,a					;a*8
	ld d,a					
	ld (_penCol),de			;load e(40) into _penCol and d into _penRow
	call _vputs				;ROM call to put the text on screen
	djnz PutNLoop			;decrement b until 0, if not 0 jump to PutALoop
	ret


PutFormulas:	
	ld a,(Name)			;load anion number into register a
	ld h,a					;these next few commands multiply anion by 11
	ld l,12
	call _HtimesL
	ld e,l
	ld d,h
	ld hl,Formulas			;hl points to anion list
	add hl,de				;add offset to list
	ld b,7					;initialize loop counter
	ld e,83					;number for _penCol
PutFLoop:
	ld a,7					;these command subtract b from 7 and multiply it by 8
	sub b					;7 - b = a
	add a,a					;a*2
	add a,a					;a*4
	add a,a					;a*8
	ld d,a					
	ld (_penCol),de			;load e(40) into _penCol and d into _penRow
	call _vputs				;ROM call to put the text on screen
	djnz PutNLoop			;decrement b until 0, if not 0 jump to PutALoop
	ret

Search:
	call GetLet
	call PutLet
	ret

GetLet:
	ld hl,Alphabet+25
	ld bc,26
	cpdr
	ret

PutLet:
	ld hl,PlaceHolder
	add hl,bc
	ld a,(hl)
	cp 0
	jr z,retto
	ld (Name),a
retto:
	ret

Alphabet:
	.db $2E,$26,$1E,$16,$0E ;A-E
	.db $2D,$25,$1D,$15,$0D ;F-J
	.db $2C,$24,$1C,$14,$0C ;K-O
	.db $2B,$23,$1B,$13,$0B ;P-T
	.db $22,$1A,$12,$0A,$21 ;U-Y
	.db $19                 ;Z

PlaceHolder:
	.db 1,9,19,37,0,39,41,42,51,0,0,54,56,64,67
	.db 70,0,0,81,91,0,0,0,0,0,98



Name:
	.db 0

Names:

	.db "                     ",0
	.db "                     ",0
	.db "                     ",0
	.db "                     ",0
	.db "Acetate              ",0
	.db "Aluminum             ",0
	.db "Amide                ",0
	.db "Ammonium             ",0
	.db "Antimony (III,V)     ",0
	.db "Arsenate, Ortho-     ",0
	.db "Arsenic (III,V)      ",0
	.db "Arsenite             ",0
	.db "Barium               ",0
	.db "Benzoate             ",0
	.db "Beryllium            ",0
	.db "Bicarbonate          ",0
	.db "Bismuth              ",0
	.db "Bisulfate            ",0
	.db "Borate               ",0
	.db "Boron                ",0
	.db "Bromate              ",0
	.db "Bromide              ",0
	.db "Cadmium              ",0
	.db "Calcium              ",0
	.db "Carbonate            ",0
	.db "Cerium (III,IV)      ",0
	.db "Cesium               ",0
	.db "Chlorate             ",0
	.db "Chlorate, Per-       ",0
	.db "Chloride             ",0
	.db "Chlorite             ",0
	.db "Chlorite, Hypo-      ",0
	.db "Chromate             ",0
	.db "Chromate, Di-        ",0
	.db "Chromium (II,III)    ",0
	.db "Citrate              ",0
	.db "Cobalt (II,III)      ",0
	.db "Copper (I,II)        ",0
	.db "Cyanate              ",0
	.db "Cyanide              ",0
	.db "Diammine silver (I)  ",0
	.db "Dihydrogen phosphate ",0
	.db "Fluoride             ",0
	.db "Formate              ",0
	.db "Gold (I,III)         ",0
	.db "Hexacyanoferrate(II) ",0
	.db "Hexacyanoferrate(III)",0
	.db "Hydride              ",0
	.db "Hydrogen             ",0
	.db "Hydrogen carbonate   ",0
	.db "Hydrogen phosphate   ",0
	.db "Hydrogen sulfate     ",0
	.db "Hydrogen sulfite     ",0
	.db "Hydroxide            ",0
	.db "Iodate               ",0
	.db "Iodide               ",0
	.db "Iron (II,III)        ",0
	.db "Lead (II,IV)         ",0
	.db "Lithium              ",0
	.db "Magnesium            ",0
	.db "Manganate            ",0
	.db "Manganate, Per-      ",0
	.db "Manganese (II,IV,VII)",0
	.db "Mercury (I)          ",0
	.db "Mercury (II)         ",0
	.db "Molybdate            ",0
	.db "Molybdenum(2,3,4,5,6)",0
	.db "Nickel               ",0
	.db "Nitrate              ",0
	.db "Nitrite              ",0
	.db "Oxalate              ",0
	.db "Oxide                ",0
	.db "Oxide, Per-          ",0
	.db "Perchlorate          ",0
	.db "Phosphate            ",0
	.db "Phosphate, Hypo-     ",0
	.db "Phosphate, Meta-     ",0
	.db "Phosphate, Ortho-    ",0
	.db "Phosphate, Pyro-     ",0
	.db "Phosphite, Hypo-     ",0
	.db "Phosphite, Ortho-    ",0
	.db "Platinum (II,IV)     ",0
	.db "Potassium            ",0
	.db "Propionate           ",0
	.db "Selenide             ",0
	.db "Selenite             ",0
	.db "Silicate, Meta-      ",0
	.db "Silicate, Ortho-     ",0
	.db "Silver               ",0
	.db "Sodium               ",0
	.db "Strontium            ",0
	.db "Sulfate              ",0
	.db "Sulfide              ",0
	.db "Sulfite              ",0
	.db "Tartarate            ",0
	.db "Telluride            ",0
	.db "Thallium (I,III)     ",0
	.db "Thiocyanate          ",0
	.db "Thiosulfate          ",0
	.db "Tin (II,IV)          ",0
	.db "Titanium (II,III,IV) ",0
	.db "Zinc                 ",0
	.db "Zirconium (II,III,IV)",0
	.db "                     ",0
	.db "                     ",0
	.db "                     ",0

Formulas:

.db "           ",0
.db "           ",0
.db "           ",0
.db "           ",0
.db "C2H3O2 -1  ",0
.db "Al +3      ",0
.db "NH2 -1     ",0
.db "NH4 +1     ",0
.db "Sb +1      ",0
.db "AsO4 -3    ",0
.db "As +1      ",0
.db "AsO3 -3    ",0
.db "Ba +2      ",0
.db "C7H5O2 -1  ",0
.db "Be +2      ",0
.db "HCO3 -1    ",0
.db "Bi +3      ",0
.db "HSO4 -1    ",0
.db "BO3 -3     ",0
.db "B +3       ",0
.db "BrO3 -1    ",0
.db "Br -1      ",0
.db "Cd +2      ",0
.db "Ca +2      ",0
.db "CO3 -2     ",0
.db "Ce +1      ",0
.db "Cs +1      ",0
.db "ClO3 -1    ",0
.db "ClO4 -1    ",0
.db "Cl -1      ",0
.db "ClO2 -1    ",0
.db "ClO -1     ",0
.db "CrO4 -2    ",0
.db "Cr2O7 -2   ",0
.db "Cr +1      ",0
.db "C6H5O7 -1  ",0
.db "Co +1      ",0
.db "Cu +1      ",0
.db "OCN -1     ",0
.db "CN -1      ",0
.db "Ag(NH3)2 +1",0
.db "H2PO4 -1   ",0
.db "F -1       ",0
.db "CHO2 -1    ",0
.db "Au +1      ",0
.db "Fe(CN)6 -4 ",0
.db "Fe(CN)6 -3 ",0
.db "H -1       ",0
.db "H +1       ",0
.db "HCO3 -1    ",0
.db "HPO4 -2    ",0
.db "HSO4 -1    ",0
.db "HSO3 -1    ",0
.db "OH -1      ",0
.db "IO3 -1     ",0
.db "I -1       ",0
.db "Fe +1      ",0
.db "Pb +1      ",0
.db "Li +1      ",0
.db "Mg +2      ",0
.db "MnO4 -2    ",0
.db "MnO4 -2    ",0
.db "Mn +1      ",0
.db "Hg +2      ",0
.db "Hg +2      ",0
.db "MoO4 -2    ",0
.db "Mo +1      ",0
.db "Ni +2      ",0
.db "NO3 -1     ",0
.db "NO2 -1     ",0
.db "C2O4 -2    ",0
.db "O -2       ",0
.db "O2 -2      ",0
.db "ClO4 -1    ",0
.db "PO4 -3     ",0
.db "P2O6 -4    ",0
.db "PO3 -1     ",0
.db "PO4 -3     ",0
.db "P2O7 -4    ",0
.db "H2PO2 -1   ",0
.db "PO3 -3     ",0
.db "Pt +1      ",0
.db "K +1       ",0
.db "C3H5O2 -1  ",0
.db "Se -2      ",0
.db "SeO3 -2    ",0
.db "SiO3 -2    ",0
.db "SiO4 -2    ",0
.db "Ag +1      ",0
.db "Na +1      ",0
.db "Sr +2      ",0
.db "SO4 -2     ",0
.db "S -2       ",0
.db "SO3 -2     ",0
.db "C4H4O6 -2  ",0
.db "Te -2      ",0
.db "Tl +1      ",0
.db "SCN -1     ",0
.db "S2O3 -2    ",0
.db "Sn +1      ",0
.db "Ti +1      ",0
.db "Zn +2      ",0
.db "Zr +1      ",0
.db "           ",0
.db "           ",0
.db "           ",0

BackGround:
;
; ASM code generated from:sol.bmp
; Created with BMP2ASM
;
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%01000000,%00000000,%00000000,%00000000,%00000000,%00000001
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%01000000,%00000000,%00000000,%00000000,%00000000,%00000001
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%01000000,%00000000,%00000000,%00000000,%00000000,%00000001
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%01000000,%00000000,%00000000,%00000000,%00000000,%00000001
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%01000000,%00000000,%00000000,%00000000,%00000000,%00000001
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%01000000,%00000000,%00000000,%00000000,%00000000,%00000001
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%01000000,%00000000,%00000000,%00000000,%00000000,%00000001
  .db %11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11111111
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000,%00000000
  .db %01111111,%11111111,%11111111,%11111111,%11111111,%11111110,%00111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11110001,%11111111,%11111111,%11111110
  .db %11101111,%11011110,%11101111,%11111111,%11111010,%11110111,%01110111,%11100011,%11011111,%11111111,%11101111,%11010111,%10111011,%11111001,%11011110,%00111111
  .db %11000111,%11011110,%01001101,%10101101,%10011011,%10010011,%01101011,%11111011,%11010101,%00101100,%11111001,%11011100,%10011011,%11110111,%10101101,%11111111
  .db %10000011,%00000110,%10101010,%10101010,%10111010,%10110111,%01100010,%00110111,%01010101,%01010101,%01101010,%11010101,%10111011,%11110111,%10001101,%00111111
  .db %11101111,%10001110,%11101010,%10101001,%11011010,%11010111,%01101011,%11101111,%01010101,%01010100,%11101010,%11010110,%10111011,%11110111,%10101101,%10111111
  .db %11101111,%11011110,%11101101,%11011100,%10011010,%10011011,%01101011,%11100011,%00010001,%01110101,%11101010,%11010100,%11011011,%11111001,%10101110,%00111111
  .db %01111111,%11111111,%11111111,%11111111,%11111111,%11111110,%00111111,%11111111,%11111111,%11111111,%11111111,%11111111,%11110001,%11111111,%11111111,%11111110

.end
